@@ -1559,7 +1559,6 @@ initarray_2Dint (int numrows, int numcolumns, int initval)
   int i, j;
   int **array;
 
-
   ZALLOC (array, numrows, int *);
   for (i = 0; i < numrows; i++) {
     ZALLOC (array[i], numcolumns, int);
@@ -1570,7 +1569,7 @@ initarray_2Dint (int numrows, int numcolumns, int initval)
 }
 
 long **
-initarray_2Dlong (int numrows, int numcolumns, int initval)
+initarray_2Dlong (int numrows, int numcolumns, long initval)
 {
   int i, j;
   long **array;
@@ -1789,6 +1788,23 @@ bal1 (double *a, int n)
 
 }
 
+double
+bal2 (double *a, int n)
+// WARNING a is input and output
+{
+  double y;
+
+  y = asum2 (a, n);
+
+  if (y <= 0.0)
+    fatalx ("bad bal2\n");
+
+  y = sqrt(y) ; 
+  vst (a, a, 1.0 / y, n);
+
+  return y;
+}
+
 double
 logmultinom (int *cc, int n)
 
@@ -2218,14 +2234,33 @@ dekodeitbb (int *xx, int kode, int len, int *baselist)
 
 }
 
+
+long expmod(long a, long b, long n) 
+{ 
+ int t ; 
+ long ax=1, bx, z, z2 ; 
+ t = b % 2 ;  
+ if (t==1) ax = a ; 
+ bx = b/2; 
+ if (bx == 0) return ax % n ; 
+ z = expmod(a, bx, n) ; 
+ z2 = (z*z) % n ; 
+ z2 = (ax*z2) % n ; 
+ 
+ return z2 ; 
+
+}
+
 long
 nextprime (long num)
-// return nextprime >= num 
+// return nextprime >= num
 {
-  long x;
+  long x, q;
   int t;
 
   for (x = num;; ++x) {
+    q = expmod(2, x-1, x) ;  
+    if (q != 1 ) continue ; 
     t = isprime (x);
     if (t == YES)
       return x;
@@ -2244,7 +2279,10 @@ isprime (long num)
     return YES;
   top = nnint (sqrt (num));
 
-  for (x = 2; x <= top; ++x) {
+  t = num % 2 ; 
+  if (t==0) return NO ;  
+
+  for (x = 3; x <= top; x += 2) {
     t = num % x;
     if (t == 0)
       return NO;
@@ -2254,6 +2292,7 @@ isprime (long num)
 
 }
 
+
 int
 irevcomp (int xx, int stringlen)
 // consists of stringlen "mininibbles" (2 bits) 
